@@ -782,7 +782,7 @@ void acpi_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = PLUGIN_NAME;
 	path[2] = NULL;
 
