@@ -57,6 +57,7 @@ static PrefParam param[] = {
 	{NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL}
 };
 
+#ifndef USE_NEW_ADDRBOOK
 static void select_addressbook_clicked_cb(GtkWidget *widget, gpointer data) {
 	const gchar *folderpath = NULL;
 	gchar *new_path = NULL;
@@ -68,6 +69,7 @@ static void select_addressbook_clicked_cb(GtkWidget *widget, gpointer data) {
 		g_free(new_path);
 	}
 }
+#endif
 
 static void addkeeper_prefs_create_widget_func(PrefsPage * _page,
 					       GtkWindow * window,
@@ -98,9 +100,13 @@ static void addkeeper_prefs_create_widget_func(PrefsPage * _page,
 
 	button = gtk_button_new_with_label(_("Select..."));
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+#ifndef USE_NEW_ADDRBOOK
 	g_signal_connect(G_OBJECT (button), "clicked",
 			 G_CALLBACK (select_addressbook_clicked_cb),
 			 entry);
+#else
+	gtk_widget_set_sensitive(button, FALSE);
+#endif
 	gtk_widget_show(button);
 	gtk_widget_show(hbox);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
@@ -192,7 +198,7 @@ void address_keeper_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 	
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = _("Address Keeper");
 	path[2] = NULL;
 
