@@ -490,7 +490,7 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 	GSList* list = NULL;
 	const gchar* res = NULL;
         AFileTest perm;
-        gchar* msg;
+        gchar* msg = NULL;
 
 	if (page->path == NULL || page->name == NULL) {
 		/* Test if page->file and page->folder has uncommitted information */
@@ -976,7 +976,6 @@ void archiver_gtk_show() {
 	GtkWidget* pax_radio_btn;
 	GtkWidget* cpio_radio_btn;
 	GtkWidget* tar_radio_btn;
-	CLAWS_TIP_DECL();
 	struct ArchivePage* page;
 	MainWindow* mainwin = mainwindow_get_mainwindow();
 
