@@ -495,11 +495,19 @@ static void gtk_message_callback(gchar *message)
 	statusbar_print_all("%s", message);
 }
 
+/* Since we do not have regular gettext.h, but are relying on glib's i18n,
+ * we need to define this here. */
+#if ENABLE_NLS
+#  define D_(domain, str) dgettext(domain, str)
+#else
+#  define D_(domain, str) (str)
+#endif
+
 gint clamav_gtk_init(void)
 {
 	static gchar *path[3];
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = _("Clam AntiVirus");
 	path[2] = NULL;
 
