@@ -43,6 +43,7 @@
 FancyPrefs fancy_prefs;
 
 static void prefs_set_proxy_entry_sens(GtkWidget *button, GtkEntry *entry_str);
+static void prefs_set_block_external_sens(GtkWidget *button, GtkWidget *open_external);
 #ifdef HAVE_LIBSOUP_GNOME    
 static void prefs_disable_fancy_proxy(GtkWidget *checkbox, GtkWidget *block);
 #endif
@@ -102,7 +103,7 @@ void fancy_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = "Fancy";
 	path[2] = NULL;
 
@@ -205,6 +206,8 @@ static void create_fancy_prefs_page(PrefsPage *page, GtkWindow *window,
 	checkbox5 = gtk_check_button_new_with_label(_("Open links with external browser"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox5),
 								 fancy_prefs.open_external);
+	g_signal_connect(G_OBJECT(checkbox2), "toggled",
+					 G_CALLBACK(prefs_set_block_external_sens), checkbox5);
 	gtk_box_pack_start(GTK_BOX(vbox), checkbox5, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox5);
 
@@ -225,6 +228,10 @@ static void prefs_set_proxy_entry_sens(GtkWidget *button, GtkEntry *entry_str) {
 	gtk_widget_set_sensitive(GTK_WIDGET(entry_str), 
 							   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
 }
+static void prefs_set_block_external_sens(GtkWidget *button, GtkWidget *open_external) {
+	gtk_widget_set_sensitive(open_external, 
+							   !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
+}
 #ifdef HAVE_LIBSOUP_GNOME    
 static void prefs_disable_fancy_proxy(GtkWidget *checkbox, GtkWidget *block) {
 	gboolean toggle = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbox));
