@@ -26,14 +26,20 @@ typedef struct _FancyPrefs FancyPrefs;
 
 struct _FancyPrefs
 {
-    WebKitWebSettings *web_settings;
-    
-    gboolean auto_load_images;
-    gboolean block_links;
-    gboolean enable_scripts;
-    gboolean enable_plugins;
-    gboolean open_external;
-    gint zoom_level;
+	WebKitWebSettings *web_settings;
+	
+	gboolean auto_load_images;
+	gboolean block_extern_content;
+	gboolean enable_scripts;
+	gboolean enable_plugins;
+	gboolean enable_java;
+	gboolean open_external;
+	gint zoom_level;
+#ifdef HAVE_LIBSOUP_GNOME    
+	gboolean enable_gnome_proxy;
+#endif
+	gboolean enable_proxy;
+	gchar *proxy_str;
 };
 
 extern FancyPrefs fancy_prefs;
