@@ -976,19 +976,7 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 	if (webkit_web_view_can_copy_clipboard(view)) {
 		GtkClipboard *wv_clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
 		const gchar *sel_text;
-#if WEBKIT_CHECK_VERSION(1,5,1)
-		viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
-		viewer->window = webkit_dom_document_get_default_view (viewer->doc);
-		viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
-		if (viewer->selection == NULL)
-			return NULL;
-		viewer->range = webkit_dom_dom_selection_get_range_at(viewer->selection, 0, NULL);
-		if (viewer->range == NULL)
-			return NULL;
-		sel_text = (const *gchar)webkit_dom_range_get_text (viewer->range);
-#else
 		sel_text = (const *gchar)webkit_web_view_get_selected_text(viewer->view);
-#endif
 		gtk_clipboard_set_text(wv_clipboard, sel_text, -1);
 	}
 	return FALSE;
@@ -1048,6 +1036,7 @@ static MimeViewer *fancy_viewer_create(void)
 	}
     
 	viewer->settings = webkit_web_settings_new();    
+	g_object_set(viewer->settings, "user-agent", "Fancy Viewer", NULL);
 	viewer->scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	viewer->tag = -1;
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(viewer->scrollwin), 
