@@ -45,6 +45,8 @@
 
 #include "pluginconfig.h"
 
+#include "gettext.h"
+
 static guint mail_receive_hook_id;
 
 static FetchinfoConfig config;
@@ -148,7 +150,8 @@ void fetchinfo_save_config(void)
 		return;
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("failed to write Fetchinfo configuration to file\n");
+		/* i18n: Possible error message during plugin load */
+		g_warning(_("failed to write Fetchinfo configuration to file\n"));
 		prefs_file_close_revert(pfile);
 		return;
 	}
@@ -169,7 +172,8 @@ gint plugin_init(gchar **error)
 
 	mail_receive_hook_id = hooks_register_hook(MAIL_RECEIVE_HOOKLIST, mail_receive_hook, NULL);
 	if (mail_receive_hook_id == (guint)-1) {
-		*error = g_strdup("Failed to register mail receive hook");
+		/* i18n: Possible error message during plugin load */
+		*error = g_strdup(_("Failed to register mail receive hook"));
 		return -1;
 	}
 
@@ -201,6 +205,10 @@ const gchar *plugin_name(void)
 
 const gchar *plugin_desc(void)
 {
+	/* i18n: Description seen in plugins dialog.
+	 * Translation of "Plugins" part of preferences path should to be
+	 * the same as translation of "Plugins" string in Claws Mail message
+	 * catalog. */
 	return _("This plugin modifies the downloaded messages. "
 	         "It inserts headers containing some download "
 		 "information: UIDL, Claws Mail account name, "
@@ -227,6 +235,7 @@ const gchar *plugin_version(void)
 struct PluginFeature *plugin_provides(void)
 {
 	static struct PluginFeature features[] = 
+		/* i18n: Description of functionality added by this plugin */
 		{ {PLUGIN_UTILITY, N_("Mail marking")},
 		  {PLUGIN_NOTHING, NULL}};
 	return features;
