@@ -52,6 +52,7 @@ typedef struct
 
 CmGDataContactsCache contacts_cache;
 gboolean cm_gdata_contacts_query_running = FALSE;
+gchar *contacts_group_id = NULL;
 
 static void write_cache_to_file(void)
 {
@@ -175,6 +176,7 @@ static void cm_gdata_query_contacts_ready(GDataContactsService *service, GAsyncR
   GError *error = NULL;
   guint num_contacts = 0;
   guint num_contacts_added = 0;
+	gchar *tmpstr1, *tmpstr2;
 
   feed = gdata_service_query_finish(GDATA_SERVICE(service), res, &error);
   cm_gdata_contacts_query_running = FALSE;
@@ -196,7 +198,13 @@ static void cm_gdata_query_contacts_ready(GDataContactsService *service, GAsyncR
   }
   g_object_unref(feed);
   contacts_cache.contacts = g_slist_reverse(contacts_cache.contacts);
-  log_message(LOG_PROTOCOL, _("GData plugin: Added %d of %d contacts to the cache\n"), num_contacts_added, num_contacts);
+	/* i18n: First part of "Added X of Y contacts to cache" */
+  tmpstr1 = g_strdup_printf(ngettext("Added %d of", "Added %d of", num_contacts_added), num_contacts_added);
+	/* i18n: Second part of "Added X of Y contacts to cache" */
+  tmpstr2 = g_strdup_printf(ngettext("1 contact to the cache", "%d contacts to the cache", num_contacts), num_contacts);
+  log_message(LOG_PROTOCOL, "%s %s\n", tmpstr1, tmpstr2);
+	g_free(tmpstr1);
+	g_free(tmpstr2);
 }
 
 static void query_after_auth(GDataContactsService *service)
@@ -206,9 +214,10 @@ static void query_after_auth(GDataContactsService *service)
   log_message(LOG_PROTOCOL, _("GData plugin: Starting async contacts query\n"));
 
   query = gdata_contacts_query_new(NULL);
+  gdata_contacts_query_set_group(query, contacts_group_id);
   gdata_query_set_max_results(GDATA_QUERY(query), cm_gdata_config.max_num_results);
   gdata_contacts_service_query_contacts_async(service, GDATA_QUERY(query), NULL, NULL, NULL,
-#ifdef HAVE_GDATA_VERSION_0_9
+#ifdef HAVE_GDATA_VERSION_0_9_1
   NULL,
 #endif
   (GAsyncReadyCallback)cm_gdata_query_contacts_ready, NULL);
@@ -216,27 +225,102 @@ static void query_after_auth(GDataContactsService *service)
   g_object_unref(query);
 }
 
+#ifdef HAVE_GDATA_VERSION_0_9_1
+static void cm_gdata_query_groups_ready(GDataContactsService *service, GAsyncResult *res, gpointer data)
+{
+  GDataFeed *feed;
+  GList *walk;
+  GError *error = NULL;
+
+  feed = gdata_service_query_finish(GDATA_SERVICE(service), res, &error);
+  if(error)
+  {
+    g_object_unref(feed);
+    log_error(LOG_PROTOCOL, _("GData plugin: Error querying for groups: %s\n"), error->message);
+    g_error_free(error);
+    return;
+  }
+
+  /* Iterate through the returned groups and search for Contacts group id */
+  for(walk = gdata_feed_get_entries(feed); walk; walk = walk->next) {
+    const gchar *system_group_id;
+    GDataContactsGroup *group = GDATA_CONTACTS_GROUP(walk->data);
+
+    system_group_id = gdata_contacts_group_get_system_group_id(group);
+    if(system_group_id && !strcmp(system_group_id, GDATA_CONTACTS_GROUP_CONTACTS)) {
+      gchar *pos;
+      const gchar *id;
+
+      id = gdata_entry_get_id(GDATA_ENTRY(group));
+
+      /* possibly replace projection "full" by "base" */
+      pos = g_strrstr(id, "/full/");
+      if(pos) {
+        GString *str = g_string_new("\0");
+        int off = pos-id;
+
+        g_string_append_len(str, id, off);
+        g_string_append(str, "/base/");
+        g_string_append(str, id+off+strlen("/full/"));
+        g_string_append_c(str, '\0');
+        contacts_group_id = str->str;
+        g_string_free(str, FALSE);
+      }
+      else
+        contacts_group_id = g_strdup(id);
+      break;
+    }
+  }
+  g_object_unref(feed);
+
+  log_message(LOG_PROTOCOL, _("GData plugin: Groups received\n"));
+
+  query_after_auth(service);
+}
+#endif
+
 #ifdef HAVE_GDATA_VERSION_0_9
+static void query_for_contacts_group_id(GDataClientLoginAuthorizer *authorizer)
+{
+  GDataContactsService *service;
+#ifdef HAVE_GDATA_VERSION_0_9_1
+
+  log_message(LOG_PROTOCOL, _("GData plugin: Starting async groups query\n"));
+
+  service = gdata_contacts_service_new(GDATA_AUTHORIZER(authorizer));
+  gdata_contacts_service_query_groups_async(service, NULL, NULL, NULL, NULL, NULL,
+      (GAsyncReadyCallback)cm_gdata_query_groups_ready, NULL);
+#else
+  service = gdata_contacts_service_new(GDATA_AUTHORIZER(authorizer));
+  query_after_auth(service);
+#endif
+  g_object_unref(service);
+}
+
 static void cm_gdata_auth_ready(GDataClientLoginAuthorizer *authorizer, GAsyncResult *res, gpointer data)
 {
   GError *error = NULL;
-  GDataContactsService *service;
 
   if(gdata_client_login_authorizer_authenticate_finish(authorizer, res, &error) == FALSE)
   {
-    log_error(LOG_PROTOCOL, _("GData plugin: Authentification error: %s\n"), error->message);
+    log_error(LOG_PROTOCOL, _("GData plugin: Authentication error: %s\n"), error->message);
     g_error_free(error);
     cm_gdata_contacts_query_running = FALSE;
     return;
   }
 
-  log_message(LOG_PROTOCOL, _("GData plugin: Authentificated\n"));
+  log_message(LOG_PROTOCOL, _("GData plugin: Authenticated\n"));
 
-  service = gdata_contacts_service_new(GDATA_AUTHORIZER(authorizer));
-
-  query_after_auth(service);
-
-  g_object_unref(service);
+  if(!contacts_group_id)
+  {
+    query_for_contacts_group_id(authorizer);
+  }
+  else {
+    GDataContactsService *service;
+    service = gdata_contacts_service_new(GDATA_AUTHORIZER(authorizer));
+    query_after_auth(service);
+    g_object_unref(service);
+  }
 }
 #else
 static void cm_gdata_auth_ready(GDataContactsService *service, GAsyncResult *res, gpointer data)
@@ -245,13 +329,13 @@ static void cm_gdata_auth_ready(GDataContactsService *service, GAsyncResult *res
 
   if(!gdata_service_authenticate_finish(GDATA_SERVICE(service), res, &error))
   {
-    log_error(LOG_PROTOCOL, _("GData plugin: Authentification error: %s\n"), error->message);
+    log_error(LOG_PROTOCOL, _("GData plugin: Authentication error: %s\n"), error->message);
     g_error_free(error);
     cm_gdata_contacts_query_running = FALSE;
     return;
   }
 
-  log_message(LOG_PROTOCOL, _("GData plugin: Authentificated\n"));
+  log_message(LOG_PROTOCOL, _("GData plugin: Authenticated\n"));
 
   query_after_auth(service);
 }
@@ -271,7 +355,7 @@ static void query()
     return;
   }
 
-  log_message(LOG_PROTOCOL, _("GData plugin: Starting async authentification\n"));
+  log_message(LOG_PROTOCOL, _("GData plugin: Starting async authentication\n"));
 
 #ifdef HAVE_GDATA_VERSION_0_9
   authorizer = gdata_client_login_authorizer_new(CM_GDATA_CLIENT_ID, GDATA_TYPE_CONTACTS_SERVICE);
@@ -345,6 +429,9 @@ gboolean cm_gdata_update_contacts_cache(void)
 
 void cm_gdata_contacts_done(void)
 {
+  g_free(contacts_group_id);
+  contacts_group_id = NULL;
+
   write_cache_to_file();
   if(contacts_cache.contacts && !claws_is_exiting())
     clear_contacts_cache();
