@@ -104,7 +104,7 @@ static void gdata_create_prefs_page(PrefsPage *page, GtkWindow *window, gpointer
   label = gtk_label_new(_("Maximum number of results:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 4, 4);
   gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-  spinner = gtk_spin_button_new_with_range(0, 1000, 50);
+  spinner = gtk_spin_button_new_with_range(0, G_MAXINT, 50);
   gtk_table_attach(GTK_TABLE(table), spinner, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 4, 4);
   gdata_page.spin_max_num_results = spinner;
 
@@ -136,7 +136,7 @@ void cm_gdata_prefs_init(void)
 {
   static gchar *path[3];
 
-  path[0] = _("Plugins");
+  path[0] = D_("claws-mail", "Plugins");
   path[1] = _("GData");
   path[2] = NULL;
 
