@@ -165,9 +165,9 @@ const gchar *plugin_name(void)
 
 const gchar *plugin_desc(void)
 {
-  return _("This plugin provides access to the GData protocoll "
+  return _("This plugin provides access to the GData protocol "
 	   "for Claws Mail.\n\n"
-      "The GData protocoll is an interface to Google services.\n"
+      "The GData protocol is an interface to Google services.\n"
       "Currently, the only implemented functionality is to include "
       "Google Contacts into the Tab-address completion.\n"
      "\nFeedback to <berndth@gmx.de> is welcome.");
