@@ -21,6 +21,8 @@
 #include "pluginconfig.h"
 
 #include <glib.h>
+#include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "pixmap_earth.h"
 
@@ -71,6 +73,9 @@
 
 #define HOSTIP_URL "http://api.hostip.info/"
 
+#define COUNTRY_RESOLVER_SUFFIX "zz.countries.nerd.dk"
+
+
 static gboolean my_messageview_show_hook(gpointer, gpointer);
 static guint hook_messageview_show;
 
@@ -79,6 +84,7 @@ static GRegex *lat_lon_from_hostip_response_regex = NULL;
 
 static GSList *container_list = NULL;
 
+static GHashTable *iso_country_hash = NULL;
 
 static gchar* get_ip_from_received_header(gchar *received)
 {
@@ -230,6 +236,35 @@ static gboolean get_lat_lon_from_ip(const gchar *ip, double *lat, double *lon)
   return TRUE;
 }
 
+/* try to look up country */
+static const gchar* get_country_from_ip(const gchar *ip)
+{
+  gchar **tok;
+  gchar *uri;
+  SoupAddress *addr;
+  const gchar *val = NULL;
+
+  tok = g_strsplit_set(ip, ".", 4);
+  if(!(tok[0] && tok[1] && tok[2] && tok[3] && !tok[4])) {
+    g_strfreev(tok);
+    debug_print("GeoLocation plugin: Error parsing ip address '%s'\n", ip);
+    return NULL;
+  }
+  uri = g_strjoin(".", tok[3], tok[2], tok[1], tok[0], COUNTRY_RESOLVER_SUFFIX, NULL);
+  g_strfreev(tok);
+
+  addr = soup_address_new(uri, SOUP_ADDRESS_ANY_PORT);
+  g_free(uri);
+
+  if(soup_address_resolve_sync(addr, NULL) == SOUP_STATUS_OK) {
+    gchar *physical = soup_address_get_physical(addr);
+    val = g_hash_table_lookup(iso_country_hash, physical);
+  }
+
+  g_object_unref(addr);
+  return val;
+}
+
 static GtkWidget* create_map_widget()
 {
   GtkWidget *map;
@@ -327,11 +362,18 @@ static void geolocation_button_toggled_cb(GtkToggleButton *button, gpointer data
       gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), page_num);
     }
     else {
-      /* TRANSLATORS: The IP address is appended to the string */
-      text = g_strconcat(_("Could not resolve location of IP address "), ip, NULL);
+      const char *country;
+
+      if(ip && ((country = get_country_from_ip(ip)) != NULL)) {
+        /* TRANSLATORS: The country name is appended to the string */
+        text = g_strconcat(_("Alleged country of origin: "), country, NULL);
+      }
+      else {
+        /* TRANSLATORS: The IP address is appended to the string */
+        text = g_strconcat(_("Could not resolve location of IP address "), ip, NULL);
+      }
       gtk_label_set_text(GTK_LABEL(label), text);
       debug_print("%s\n", text);
-
       gtk_toggle_button_set_active(button, FALSE);
     }
     g_free(text);
@@ -479,6 +521,253 @@ static gboolean my_messageview_show_hook(gpointer source, gpointer data)
   return FALSE;
 }
 
+#define ISO_IN(k,v) g_hash_table_insert(iso_country_hash, (k), (v))
+static void fill_iso_country_hash(void)
+{
+  iso_country_hash = g_hash_table_new(g_str_hash, g_str_equal);
+  ISO_IN("127.0.0.20", _("Andorra"));
+  ISO_IN("127.0.3.16", _("United Arab Emirates"));
+  ISO_IN("127.0.0.4", _("Afghanistan"));
+  ISO_IN("127.0.0.28", _("Antigua And Barbuda"));
+  ISO_IN("127.0.2.148", _("Anguilla"));
+  ISO_IN("127.0.0.8", _("Albania"));
+  ISO_IN("127.0.0.51", _("Armenia"));
+  ISO_IN("127.0.2.18", _("Netherlands Antilles"));
+  ISO_IN("127.0.0.24", _("Angola"));
+  ISO_IN("127.0.0.10", _("Antarctica"));
+  ISO_IN("127.0.0.32", _("Argentina"));
+  ISO_IN("127.0.0.16", _("American Samoa"));
+  ISO_IN("127.0.0.40", _("Austria"));
+  ISO_IN("127.0.0.36", _("Australia"));
+  ISO_IN("127.0.2.21", _("Aruba"));
+  ISO_IN("127.0.0.31", _("Azerbaijan"));
+  ISO_IN("127.0.0.70", _("Bosnia And Herzegovina"));
+  ISO_IN("127.0.0.52", _("Barbados"));
+  ISO_IN("127.0.0.50", _("Bangladesh"));
+  ISO_IN("127.0.0.56", _("Belgium"));
+  ISO_IN("127.0.3.86", _("Burkina Faso"));
+  ISO_IN("127.0.0.100", _("Bulgaria"));
+  ISO_IN("127.0.0.48", _("Bahrain"));
+  ISO_IN("127.0.0.108", _("Burundi"));
+  ISO_IN("127.0.0.204", _("Benin"));
+  ISO_IN("127.0.0.60", _("Bermuda"));
+  ISO_IN("127.0.0.96", _("Brunei Darussalam"));
+  ISO_IN("127.0.0.68", _("Bolivia"));
+  ISO_IN("127.0.0.76", _("Brazil"));
+  ISO_IN("127.0.0.44", _("Bahamas"));
+  ISO_IN("127.0.0.64", _("Bhutan"));
+  ISO_IN("127.0.0.74", _("Bouvet Island"));
+  ISO_IN("127.0.0.72", _("Botswana"));
+  ISO_IN("127.0.0.112", _("Belarus"));
+  ISO_IN("127.0.0.84", _("Belize"));
+  ISO_IN("127.0.0.124", _("Canada"));
+  ISO_IN("127.0.0.166", _("Cocos (Keeling) Islands"));
+  ISO_IN("127.0.0.140", _("Central African Republic"));
+  ISO_IN("127.0.0.178", _("Congo"));
+  ISO_IN("127.0.2.244", _("Switzerland"));
+  ISO_IN("127.0.1.128", _("Cote D'Ivoire"));
+  ISO_IN("127.0.0.184", _("Cook Islands"));
+  ISO_IN("127.0.0.152", _("Chile"));
+  ISO_IN("127.0.0.120", _("Cameroon"));
+  ISO_IN("127.0.0.156", _("China"));
+  ISO_IN("127.0.0.170", _("Colombia"));
+  ISO_IN("127.0.0.188", _("Costa Rica"));
+  ISO_IN("127.0.0.192", _("Cuba"));
+  ISO_IN("127.0.0.132", _("Cape Verde"));
+  ISO_IN("127.0.0.162", _("Christmas Island"));
+  ISO_IN("127.0.0.196", _("Cyprus"));
+  ISO_IN("127.0.0.203", _("Czech Republic"));
+  ISO_IN("127.0.1.20", _("Germany"));
+  ISO_IN("127.0.1.6", _("Djibouti"));
+  ISO_IN("127.0.0.208", _("Denmark"));
+  ISO_IN("127.0.0.212", _("Dominica"));
+  ISO_IN("127.0.0.214", _("Dominican Republic"));
+  ISO_IN("127.0.0.12", _("Algeria"));
+  ISO_IN("127.0.0.218", _("Ecuador"));
+  ISO_IN("127.0.0.233", _("Estonia"));
+  ISO_IN("127.0.3.50", _("Egypt"));
+  ISO_IN("127.0.2.220", _("Western Sahara"));
+  ISO_IN("127.0.0.232", _("Eritrea"));
+  ISO_IN("127.0.2.212", _("Spain"));
+  ISO_IN("127.0.0.231", _("Ethiopia"));
+  ISO_IN("127.0.0.246", _("Finland"));
+  ISO_IN("127.0.0.242", _("Fiji"));
+  ISO_IN("127.0.0.238", _("Falkland Islands (Malvinas)"));
+  ISO_IN("127.0.2.71", _("Micronesia, Federated States Of"));
+  ISO_IN("127.0.0.234", _("Faroe Islands"));
+  ISO_IN("127.0.0.250", _("France"));
+  ISO_IN("127.0.0.249", _("France, Metropolitan"));
+  ISO_IN("127.0.1.10", _("Gabon"));
+  ISO_IN("127.0.3.58", _("United Kingdom"));
+  ISO_IN("127.0.1.52", _("Grenada"));
+  ISO_IN("127.0.1.12", _("Georgia"));
+  ISO_IN("127.0.0.254", _("French Guiana"));
+  ISO_IN("127.0.1.32", _("Ghana"));
+  ISO_IN("127.0.1.36", _("Gibraltar"));
+  ISO_IN("127.0.1.48", _("Greenland"));
+  ISO_IN("127.0.1.14", _("Gambia"));
+  ISO_IN("127.0.1.68", _("Guinea"));
+  ISO_IN("127.0.1.56", _("Guadeloupe"));
+  ISO_IN("127.0.0.226", _("Equatorial Guinea"));
+  ISO_IN("127.0.1.44", _("Greece"));
+  ISO_IN("127.0.0.239", _("South Georgia And The South Sandwich Islands"));
+  ISO_IN("127.0.1.64", _("Guatemala"));
+  ISO_IN("127.0.1.60", _("Guam"));
+  ISO_IN("127.0.2.112", _("Guinea-Bissau"));
+  ISO_IN("127.0.1.72", _("Guyana"));
+  ISO_IN("127.0.1.88", _("Hong Kong"));
+  ISO_IN("127.0.1.78", _("Heard Island And Mcdonald Islands"));
+  ISO_IN("127.0.1.84", _("Honduras"));
+  ISO_IN("127.0.0.191", _("Croatia"));
+  ISO_IN("127.0.1.76", _("Haiti"));
+  ISO_IN("127.0.1.92", _("Hungary"));
+  ISO_IN("127.0.1.104", _("Indonesia"));
+  ISO_IN("127.0.1.116", _("Ireland"));
+  ISO_IN("127.0.1.120", _("Israel"));
+  ISO_IN("127.0.1.100", _("India"));
+  ISO_IN("127.0.0.86", _("British Indian Ocean Territory"));
+  ISO_IN("127.0.1.112", _("Iraq"));
+  ISO_IN("127.0.1.108", _("Iran, Islamic Republic Of"));
+  ISO_IN("127.0.1.96", _("Iceland"));
+  ISO_IN("127.0.1.124", _("Italy"));
+  ISO_IN("127.0.1.132", _("Jamaica"));
+  ISO_IN("127.0.1.144", _("Jordan"));
+  ISO_IN("127.0.1.136", _("Japan"));
+  ISO_IN("127.0.1.148", _("Kenya"));
+  ISO_IN("127.0.1.161", _("Kyrgyzstan"));
+  ISO_IN("127.0.0.116", _("Cambodia"));
+  ISO_IN("127.0.1.40", _("Kiribati"));
+  ISO_IN("127.0.0.174", _("Comoros"));
+  ISO_IN("127.0.2.147", _("Saint Kitts And Nevis"));
+  ISO_IN("127.0.1.152", _("Korea, Democratic People'S Republic Of"));
+  ISO_IN("127.0.1.154", _("Korea, Republic Of"));
+  ISO_IN("127.0.1.158", _("Kuwait"));
+  ISO_IN("127.0.0.136", _("Cayman Islands"));
+  ISO_IN("127.0.1.142", _("Kazakhstan"));
+  ISO_IN("127.0.1.162", _("Lao People'S Democratic Republic"));
+  ISO_IN("127.0.1.166", _("Lebanon"));
+  ISO_IN("127.0.2.150", _("Saint Lucia"));
+  ISO_IN("127.0.1.182", _("Liechtenstein"));
+  ISO_IN("127.0.0.144", _("Sri Lanka"));
+  ISO_IN("127.0.1.174", _("Liberia"));
+  ISO_IN("127.0.1.170", _("Lesotho"));
+  ISO_IN("127.0.1.184", _("Lithuania"));
+  ISO_IN("127.0.1.186", _("Luxembourg"));
+  ISO_IN("127.0.1.172", _("Latvia"));
+  ISO_IN("127.0.1.178", _("Libyan Arab Jamahiriya"));
+  ISO_IN("127.0.1.248", _("Morocco"));
+  ISO_IN("127.0.1.236", _("Monaco"));
+  ISO_IN("127.0.1.242", _("Moldova, Republic Of"));
+  ISO_IN("127.0.1.194", _("Madagascar"));
+  ISO_IN("127.0.2.72", _("Marshall Islands"));
+  ISO_IN("127.0.3.39", _("Macedonia, The Former Yugoslav Republic Of"));
+  ISO_IN("127.0.1.210", _("Mali"));
+  ISO_IN("127.0.0.104", _("Myanmar"));
+  ISO_IN("127.0.1.240", _("Mongolia"));
+  ISO_IN("127.0.1.190", _("Macao"));
+  ISO_IN("127.0.2.68", _("Northern Mariana Islands"));
+  ISO_IN("127.0.1.218", _("Martinique"));
+  ISO_IN("127.0.1.222", _("Mauritania"));
+  ISO_IN("127.0.1.244", _("Montserrat"));
+  ISO_IN("127.0.1.214", _("Malta"));
+  ISO_IN("127.0.1.224", _("Mauritius"));
+  ISO_IN("127.0.1.206", _("Maldives"));
+  ISO_IN("127.0.1.198", _("Malawi"));
+  ISO_IN("127.0.1.228", _("Mexico"));
+  ISO_IN("127.0.1.202", _("Malaysia"));
+  ISO_IN("127.0.1.252", _("Mozambique"));
+  ISO_IN("127.0.2.4", _("Namibia"));
+  ISO_IN("127.0.2.28", _("New Caledonia"));
+  ISO_IN("127.0.2.50", _("Niger"));
+  ISO_IN("127.0.2.62", _("Norfolk Island"));
+  ISO_IN("127.0.2.54", _("Nigeria"));
+  ISO_IN("127.0.2.46", _("Nicaragua"));
+  ISO_IN("127.0.2.16", _("Netherlands"));
+  ISO_IN("127.0.2.66", _("Norway"));
+  ISO_IN("127.0.2.12", _("Nepal"));
+  ISO_IN("127.0.2.8", _("Nauru"));
+  ISO_IN("127.0.2.58", _("Niue"));
+  ISO_IN("127.0.2.42", _("New Zealand"));
+  ISO_IN("127.0.2.0", _("Oman"));
+  ISO_IN("127.0.2.79", _("Panama"));
+  ISO_IN("127.0.2.92", _("Peru"));
+  ISO_IN("127.0.1.2", _("French Polynesia"));
+  ISO_IN("127.0.2.86", _("Papua New Guinea"));
+  ISO_IN("127.0.2.96", _("Philippines"));
+  ISO_IN("127.0.2.74", _("Pakistan"));
+  ISO_IN("127.0.2.104", _("Poland"));
+  ISO_IN("127.0.2.154", _("Saint Pierre And Miquelon"));
+  ISO_IN("127.0.2.100", _("Pitcairn"));
+  ISO_IN("127.0.2.118", _("Puerto Rico"));
+  ISO_IN("127.0.2.108", _("Portugal"));
+  ISO_IN("127.0.2.73", _("Palau"));
+  ISO_IN("127.0.2.88", _("Paraguay"));
+  ISO_IN("127.0.2.122", _("Qatar"));
+  ISO_IN("127.0.2.126", _("Reunion"));
+  ISO_IN("127.0.2.130", _("Romania"));
+  ISO_IN("127.0.2.131", _("Russian Federation"));
+  ISO_IN("127.0.2.134", _("Rwanda"));
+  ISO_IN("127.0.2.170", _("Saudi Arabia"));
+  ISO_IN("127.0.0.90", _("Solomon Islands"));
+  ISO_IN("127.0.2.178", _("Seychelles"));
+  ISO_IN("127.0.2.224", _("Sudan"));
+  ISO_IN("127.0.2.240", _("Sweden"));
+  ISO_IN("127.0.2.190", _("Singapore"));
+  ISO_IN("127.0.2.142", _("Saint Helena"));
+  ISO_IN("127.0.2.193", _("Slovenia"));
+  ISO_IN("127.0.2.232", _("Svalbard And Jan Mayen"));
+  ISO_IN("127.0.2.191", _("Slovakia"));
+  ISO_IN("127.0.2.182", _("Sierra Leone"));
+  ISO_IN("127.0.2.162", _("San Marino"));
+  ISO_IN("127.0.2.174", _("Senegal"));
+  ISO_IN("127.0.2.194", _("Somalia"));
+  ISO_IN("127.0.2.228", _("Suriname"));
+  ISO_IN("127.0.2.166", _("Sao Tome And Principe"));
+  ISO_IN("127.0.0.222", _("El Salvador"));
+  ISO_IN("127.0.2.248", _("Syrian Arab Republic"));
+  ISO_IN("127.0.2.236", _("Swaziland"));
+  ISO_IN("127.0.3.28", _("Turks And Caicos Islands"));
+  ISO_IN("127.0.0.148", _("Chad"));
+  ISO_IN("127.0.1.4", _("French Southern Territories"));
+  ISO_IN("127.0.3.0", _("Togo"));
+  ISO_IN("127.0.2.252", _("Thailand"));
+  ISO_IN("127.0.2.250", _("Tajikistan"));
+  ISO_IN("127.0.3.4", _("Tokelau"));
+  ISO_IN("127.0.3.27", _("Turkmenistan"));
+  ISO_IN("127.0.3.20", _("Tunisia"));
+  ISO_IN("127.0.3.8", _("Tonga"));
+  ISO_IN("127.0.2.114", _("East Timor"));
+  ISO_IN("127.0.3.24", _("Turkey"));
+  ISO_IN("127.0.3.12", _("Trinidad And Tobago"));
+  ISO_IN("127.0.3.30", _("Tuvalu"));
+  ISO_IN("127.0.0.158", _("Taiwan, Province Of China"));
+  ISO_IN("127.0.3.66", _("Tanzania, United Republic Of"));
+  ISO_IN("127.0.3.36", _("Ukraine"));
+  ISO_IN("127.0.3.32", _("Uganda"));
+  ISO_IN("127.0.3.58", _("United Kingdom"));
+  ISO_IN("127.0.2.69", _("United States Minor Outlying Islands"));
+  ISO_IN("127.0.3.72", _("United States"));
+  ISO_IN("127.0.3.90", _("Uruguay"));
+  ISO_IN("127.0.3.92", _("Uzbekistan"));
+  ISO_IN("127.0.1.80", _("Holy See (Vatican City State)"));
+  ISO_IN("127.0.2.158", _("Saint Vincent And The Grenadines"));
+  ISO_IN("127.0.3.94", _("Venezuela"));
+  ISO_IN("127.0.0.92", _("Virgin Islands, British"));
+  ISO_IN("127.0.3.82", _("Virgin Islands, U.S."));
+  ISO_IN("127.0.2.192", _("Viet Nam"));
+  ISO_IN("127.0.2.36", _("Vanuatu"));
+  ISO_IN("127.0.3.108", _("Wallis And Futuna"));
+  ISO_IN("127.0.3.114", _("Samoa"));
+  ISO_IN("127.0.3.119", _("Yemen"));
+  ISO_IN("127.0.0.175", _("Mayotte"));
+  ISO_IN("127.0.3.123", _("Serbia And Montenegro"));
+  ISO_IN("127.0.2.198", _("South Africa"));
+  ISO_IN("127.0.3.126", _("Zambia"));
+  ISO_IN("127.0.0.180", _("Democratic Republic Of The Congo"));
+  ISO_IN("127.0.2.204", _("Zimbabwe"));
+}
+#undef ISO_IN
+
 gint plugin_init(gchar **error)
 {
   GError *err = NULL;
@@ -524,6 +813,8 @@ gint plugin_init(gchar **error)
     return -1;
   }
 
+  fill_iso_country_hash();
+
   debug_print("GeoLocation plugin loaded\n");
 
   return 0;
@@ -560,6 +851,11 @@ gboolean plugin_done(void)
       g_regex_unref(lat_lon_from_hostip_response_regex);
       lat_lon_from_hostip_response_regex = NULL;
     }
+
+    if(iso_country_hash) {
+      g_hash_table_destroy(iso_country_hash);
+      iso_country_hash = NULL;
+    }
   }
 
   debug_print("GeoLocation plugin unloaded\n");
