@@ -59,7 +59,7 @@ html_embedded_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	
 	bin = GTK_BIN (widget);
 
-	if (bin->child && gtkut_widget_get_visible (bin->child)) {
+	if (bin->child && gtk_widget_get_visible (bin->child)) {
 		gtk_widget_size_allocate(bin->child, allocation);
 	}
 	widget->allocation = *allocation;
