@@ -74,6 +74,7 @@ static PrefParam param[] = {
 
 static GtkHtmlBrowserPage gtkhtml_prefs_page;
 
+#ifndef USE_NEW_ADDRBOOK
 static void gtkhtml_whitelist_ab_select_cb(GtkWidget *widget, gpointer data)
 {
 	GtkHtmlBrowserPage *page = (GtkHtmlBrowserPage *) data;
@@ -87,6 +88,7 @@ static void gtkhtml_whitelist_ab_select_cb(GtkWidget *widget, gpointer data)
 		g_free(new_path);
 	}
 }
+#endif
 
 static void create_gtkhtml_prefs_page	(PrefsPage *page,
 					 GtkWindow *window,
@@ -99,7 +101,7 @@ void gtkhtml_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = _("GtkHtml2 Viewer");
 	path[2] = NULL;
 
@@ -131,9 +133,10 @@ static void local_checkbox_toggled(GtkToggleButton *button,
 	gtk_widget_set_sensitive(prefs_page->whitelist_ab, active);
 	gtk_widget_set_sensitive(prefs_page->whitelist_ab_folder_combo, active && 
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_page->whitelist_ab)));
+#ifndef USE_NEW_ADDRBOOK
 	gtk_widget_set_sensitive(prefs_page->whitelist_ab_select_btn, active && 
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_page->whitelist_ab)));
-	
+#endif	
 	active &= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_page->cache_images));
 }
 
@@ -146,7 +149,9 @@ static void whitelist_checkbox_toggled(GtkToggleButton *button,
 	active &= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_page->local));
 
 	gtk_widget_set_sensitive(prefs_page->whitelist_ab_folder_combo, active);
+#ifndef USE_NEW_ADDRBOOK
 	gtk_widget_set_sensitive(prefs_page->whitelist_ab_select_btn, active);
+#endif
 }
 
 static void cache_images_checkbox_toggled(GtkToggleButton *button,
@@ -263,17 +268,21 @@ static void create_gtkhtml_prefs_page(PrefsPage *page,
 
 	gtk_widget_set_sensitive(whitelist_ab_checkbtn, !gtkhtml_prefs.local);
 	gtk_widget_set_sensitive(whitelist_ab_folder_combo, !gtkhtml_prefs.local && gtkhtml_prefs.whitelist_ab);
+#ifndef USE_NEW_ADDRBOOK
 	gtk_widget_set_sensitive(whitelist_ab_select_btn, !gtkhtml_prefs.local && gtkhtml_prefs.whitelist_ab);
-
+#else
+	gtk_widget_set_sensitive(whitelist_ab_select_btn, FALSE);
+#endif
 	g_signal_connect(G_OBJECT(cache_images_checkbox), "toggled",
 			 G_CALLBACK(cache_images_checkbox_toggled),
 			 prefs_page);
 	g_signal_connect(G_OBJECT(empty_cache_btn), "clicked",
 			 G_CALLBACK(empty_cache_btn_clicked),
 			 prefs_page);
+#ifndef USE_NEW_ADDRBOOK
 	g_signal_connect(G_OBJECT (whitelist_ab_select_btn), "clicked",
 			 G_CALLBACK(gtkhtml_whitelist_ab_select_cb), page);
-
+#endif
         prefs_page->local = local_checkbox;
         prefs_page->cache_images = cache_images_checkbox;
         prefs_page->clear_cache = clear_cache_checkbox;
