@@ -80,7 +80,7 @@ void notification_toggle_hide_show_window(void)
   if((mainwin = mainwindow_get_mainwindow()) == NULL)
     return;
 
-  if(gtkut_widget_get_visible(GTK_WIDGET(mainwin->window))) {
+  if(gtk_widget_get_visible(GTK_WIDGET(mainwin->window))) {
     if((gdk_window_get_state(GTK_WIDGET(mainwin->window)->window)&GDK_WINDOW_STATE_ICONIFIED)
        || mainwindow_is_obscured()) {
       notification_show_mainwindow(mainwin);
@@ -112,7 +112,6 @@ void notification_update_msg_counts(FolderItem *removed_item)
   }
   msg_count_clear(&msg_count);
   g_hash_table_foreach(msg_count_hash, msg_count_update_from_hash, NULL);
-
 #ifdef NOTIFICATION_LCDPROC
   notification_update_lcdproc();
 #endif
