@@ -36,7 +36,12 @@
 #include "prefs_common.h"
 #include "alertpanel.h"
 #include "gtk/menu.h"
-#include "addrindex.h"
+#ifndef USE_NEW_ADDRBOOK
+    #include "addrindex.h"
+#else
+    #include "addressbook-dbus.h"
+#endif
+
 #include "gtk/manage_window.h"
 #include "common/utils.h"
 #include "gtk/gtkutils.h"
@@ -481,7 +486,17 @@ static void trayicon_compose_acc_cb(GtkMenuItem *menuitem, gpointer data)
 
 static void trayicon_addressbook_cb(GtkAction *action, gpointer data)
 {
-  addressbook_open(NULL);
+#ifndef USE_NEW_ADDRBOOK
+    addressbook_open(NULL);
+#else
+    GError* error = NULL;
+
+    addressbook_dbus_open(FALSE, &error);
+    if (error) {
+	g_warning("%s", error->message);
+	g_error_free(error);
+    }
+#endif
 }
 
 static void trayicon_toggle_offline_cb(GtkAction *action, gpointer data)
@@ -646,6 +661,7 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
 
   /* Icon */
   pixbuf = NULL;
+#ifndef USE_NEW_ADDRBOOK
   if(msginfo && msginfo->from) {
     gchar *icon_path;
     icon_path = addrindex_get_picture_file(msginfo->from);
@@ -670,6 +686,7 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
       debug_print("Picture path does not exist: %s\n",icon_path);
     g_free(icon_path);
   }
+#endif
   if(!pixbuf)
     pixbuf = g_object_ref(notification_pixbuf_get(NOTIFICATION_CM_LOGO_64x64));
 
