@@ -22,6 +22,11 @@
 #include "poppler_viewer.h"
 #include "printing.h"
 #include "prefs_common.h"
+#include "gtk/gtkutils.h"
+#ifndef POPPLER_WITH_GDK
+#include "stdbool.h"
+#include <goo/gtypes.h>
+#endif
 
 static FileType pdf_viewer_mimepart_get_type(MimeInfo *partinfo);
 static MimeViewerFactory pdf_viewer_factory;
@@ -76,7 +81,6 @@ static void pdf_viewer_button_document_info_cb(GtkButton *button, PdfViewer *vie
 static void pdf_viewer_show_controls(PdfViewer *viewer, gboolean show);
 static gboolean pdf_viewer_scroll_page(MimeViewer *_viewer, gboolean up);
 static void pdf_viewer_scroll_one_line(MimeViewer *_viewer, gboolean up);
-static void button_set_pixmap(GtkWidget *widg, char **button_image);
 
 /** Claws-Mail Plugin functions*/
 gint plugin_init(gchar **error);
@@ -87,6 +91,135 @@ const gchar *plugin_licence(void);
 const gchar *plugin_version(void);
 struct PluginFeature *plugin_provides(void);
 
+#ifndef POPPLER_WITH_GDK
+static void
+copy_cairo_surface_to_pixbuf (cairo_surface_t *surface,
+			      GdkPixbuf       *pixbuf)
+{
+	int cairo_width, cairo_height, cairo_rowstride;
+	unsigned char *pixbuf_data, *dst, *cairo_data;
+	int pixbuf_rowstride, pixbuf_n_channels;
+	unsigned int *src;
+	int x, y;
+
+	cairo_width = cairo_image_surface_get_width (surface);
+	cairo_height = cairo_image_surface_get_height (surface);
+	cairo_rowstride = cairo_image_surface_get_stride (surface);
+	cairo_data = cairo_image_surface_get_data (surface);
+
+	pixbuf_data = gdk_pixbuf_get_pixels (pixbuf);
+	pixbuf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+	pixbuf_n_channels = gdk_pixbuf_get_n_channels (pixbuf);
+
+	if (cairo_width > gdk_pixbuf_get_width (pixbuf))
+		cairo_width = gdk_pixbuf_get_width (pixbuf);
+	if (cairo_height > gdk_pixbuf_get_height (pixbuf))
+		cairo_height = gdk_pixbuf_get_height (pixbuf);
+	for (y = 0; y < cairo_height; y++) {
+		src = (unsigned int *) (cairo_data + y * cairo_rowstride);
+		dst = pixbuf_data + y * pixbuf_rowstride;
+		for (x = 0; x < cairo_width; x++) {
+			dst[0] = (*src >> 16) & 0xff;
+			dst[1] = (*src >> 8) & 0xff; 
+			dst[2] = (*src >> 0) & 0xff;
+			if (pixbuf_n_channels == 4)
+				dst[3] = (*src >> 24) & 0xff;
+			dst += pixbuf_n_channels;
+			src++;
+		}
+    }
+}
+static void
+_poppler_page_render_to_pixbuf (PopplerPage *page,
+				int src_x, int src_y,
+				int src_width, int src_height,
+				double scale,
+				int rotation,
+				GBool printing,
+				GdkPixbuf *pixbuf)
+{
+	cairo_t *cr;
+	cairo_surface_t *surface;
+
+	surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+					src_width, src_height);
+	cr = cairo_create (surface);
+	cairo_save (cr);
+	switch (rotation) {
+	case 90:
+		cairo_translate (cr, src_x + src_width, -src_y);
+		break;
+	case 180:
+		cairo_translate (cr, src_x + src_width, src_y + src_height);
+		break;
+	case 270:
+		cairo_translate (cr, -src_x, src_y + src_height);
+		break;
+	default:
+		cairo_translate (cr, -src_x, -src_y);
+	}
+
+	if (scale != 1.0)
+		cairo_scale (cr, scale, scale);
+
+	if (rotation != 0)
+		cairo_rotate (cr, rotation * G_PI / 180.0);
+
+	if (printing)
+		poppler_page_render_for_printing (page, cr);
+	else
+		poppler_page_render (page, cr);
+	cairo_restore (cr);
+
+	cairo_set_operator (cr, CAIRO_OPERATOR_DEST_OVER);
+	cairo_set_source_rgb (cr, 1., 1., 1.);
+	cairo_paint (cr);
+
+	cairo_destroy (cr);
+
+	copy_cairo_surface_to_pixbuf (surface, pixbuf);
+	cairo_surface_destroy (surface);
+}
+
+/**
+ * poppler_page_render_to_pixbuf:
+ * @page: the page to render from
+ * @src_x: x coordinate of upper left corner  
+ * @src_y: y coordinate of upper left corner  
+ * @src_width: width of rectangle to render  
+ * @src_height: height of rectangle to render
+ * @scale: scale specified as pixels per point
+ * @rotation: rotate the document by the specified degree
+ * @pixbuf: pixbuf to render into
+ *
+ * First scale the document to match the specified pixels per point,
+ * then render the rectangle given by the upper left corner at
+ * (src_x, src_y) and src_width and src_height.
+ * This function is for rendering a page that will be displayed.
+ * If you want to render a page that will be printed use
+ * poppler_page_render_to_pixbuf_for_printing() instead
+ *
+ * Deprecated: 0.16
+ **/
+static void
+poppler_page_render_to_pixbuf (PopplerPage *page,
+			       int src_x, int src_y,
+			       int src_width, int src_height,
+			       double scale,
+			       int rotation,
+			       GdkPixbuf *pixbuf)
+{
+	g_return_if_fail (POPPLER_IS_PAGE (page));
+	g_return_if_fail (scale > 0.0);
+	g_return_if_fail (pixbuf != NULL);
+
+	_poppler_page_render_to_pixbuf (page, src_x, src_y,
+				  src_width, src_height,
+				  scale, rotation,
+				  gFalse,
+				  pixbuf);
+}
+#endif
 static GtkWidget *pdf_viewer_get_widget(MimeViewer *_viewer)
 {
 	PdfViewer *viewer = (PdfViewer *) _viewer;
@@ -478,14 +611,14 @@ static void pdf_viewer_set_index_button_sensitive(PdfViewer *viewer)
 {
 	viewer->pdf_index  = poppler_index_iter_new(viewer->pdf_doc);
 	if (viewer->pdf_index) {	
-		if (!GTK_WIDGET_IS_SENSITIVE(viewer->doc_index)) {
+		if (!gtk_widget_is_sensitive(viewer->doc_index)) {
 			gtk_widget_set_sensitive(viewer->doc_index, TRUE);
 		}
 	}
 	else {
 		gtk_widget_set_sensitive(viewer->doc_index, FALSE);
 	}
-    
+
     poppler_index_iter_free(viewer->pdf_index);
     viewer->pdf_index = NULL;
 }
@@ -532,6 +665,8 @@ static GtkTable * pdf_viewer_fill_info_table(PdfViewer *viewer)
 	PopplerPermissions permissions;
 	PopplerViewerPreferences view_prefs;
 
+        title = format = author = subject = keywords = creator = producer = linearized = tmp = 0;
+
 	g_object_get(viewer->pdf_doc,
 				"title", &title,
 				"format", &format,
@@ -1102,29 +1237,24 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 		}
 		
 		if (pdf_viewer_mimepart_get_type(viewer->to_load) == TYPE_PS) {
-			stock_pixmap_gdk(viewer->hbox, 
+			stock_pixbuf_gdk(viewer->hbox, 
 					STOCK_PIXMAP_MIME_PS, 
-					&viewer->icon_pixmap, 
-					&viewer->icon_bitmap);
-		gtk_image_set_from_pixmap(GTK_IMAGE(viewer->icon_type), viewer->icon_pixmap, viewer->icon_bitmap);
+					&viewer->icon_pixbuf);
+		gtk_image_set_from_pixbuf(GTK_IMAGE(viewer->icon_type), viewer->icon_pixbuf);
 		} 
 		else if (pdf_viewer_mimepart_get_type(viewer->to_load) == TYPE_PDF) {
-			stock_pixmap_gdk(viewer->hbox, 
+			stock_pixbuf_gdk(viewer->hbox, 
 			STOCK_PIXMAP_MIME_PDF, 
-			&viewer->icon_pixmap, 
-			&viewer->icon_bitmap);
-			gtk_image_set_from_pixmap(GTK_IMAGE(viewer->icon_type), 
-									viewer->icon_pixmap, 
-									viewer->icon_bitmap);
+			&viewer->icon_pixbuf);
+			gtk_image_set_from_pixbuf(GTK_IMAGE(viewer->icon_type), 
+									viewer->icon_pixbuf);
 		} 
 		else {
-			stock_pixmap_gdk(viewer->hbox, 
+			stock_pixbuf_gdk(viewer->hbox, 
 			STOCK_PIXMAP_MIME_APPLICATION, 
-			&viewer->icon_pixmap, 
-			&viewer->icon_bitmap);
-			gtk_image_set_from_pixmap(GTK_IMAGE(viewer->icon_type), 
-									viewer->icon_pixmap, 
-									viewer->icon_bitmap);
+			&viewer->icon_pixbuf);
+			gtk_image_set_from_pixbuf(GTK_IMAGE(viewer->icon_type), 
+									viewer->icon_pixbuf);
 		}
 
 		gtk_label_set_text(GTK_LABEL(viewer->doc_label), _("Loading..."));	
@@ -1157,7 +1287,7 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 			}
 			
 			g_free(cmdline);
-			g_unlink(tmpfile);
+			claws_unlink(tmpfile);
 			g_free(tmpfile);
 			if (result != 0) {
 				main_window_cursor_normal(mainwindow_get_mainwindow());
@@ -1178,10 +1308,9 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 		g_signal_handlers_unblock_by_func(G_OBJECT(viewer->cur_page), pdf_viewer_spin_change_page_cb,(gpointer *)viewer);
 		gtk_spin_button_spin(GTK_SPIN_BUTTON(viewer->cur_page), GTK_SPIN_HOME, 1);
 		tmp = g_strdup_printf(_("%s Document"),pdf_viewer_mimepart_get_type(viewer->to_load) == TYPE_PDF ? "PDF":"Postscript");
-		gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips),
+		CLAWS_SET_TIP(
 				GTK_WIDGET(viewer->icon_type_ebox),
-				tmp,
-				NULL);
+				tmp);
 		g_free(tmp);
 
 		tmp = g_strdup_printf(ngettext("%d page", "%d pages", viewer->num_pages),
@@ -1195,12 +1324,11 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 	if (viewer->pdf_doc == NULL) {
 	
 		strretchomp(error->message);
-		stock_pixmap_gdk(viewer->hbox, 
+		stock_pixbuf_gdk(viewer->hbox, 
 				STOCK_PIXMAP_MIME_APPLICATION, 
-				&viewer->icon_pixmap, 
-				&viewer->icon_bitmap);
+				&viewer->icon_pixbuf);
 
-		gtk_image_set_from_pixmap(GTK_IMAGE(viewer->icon_type), viewer->icon_pixmap, viewer->icon_bitmap);
+		gtk_image_set_from_pixbuf(GTK_IMAGE(viewer->icon_type), viewer->icon_pixbuf);
 		gtk_label_set_text(GTK_LABEL(viewer->doc_label), error->message);
 	
 		pdf_viewer_show_controls(viewer, FALSE);
@@ -1288,7 +1416,7 @@ static void pdf_viewer_show_mimepart(MimeViewer *_viewer, const gchar *infile,
 	debug_print("pdf_viewer_show_mimepart\n");
 
 	if (viewer->filename != NULL) {
-		g_unlink(viewer->filename);
+		claws_unlink(viewer->filename);
 		g_free(viewer->filename);
 		viewer->filename = NULL;
 	}
@@ -1359,12 +1487,12 @@ static void pdf_viewer_destroy(MimeViewer *_viewer)
 	if (viewer->pdf_index) poppler_index_iter_free(viewer->pdf_index);
 
 	poppler_page_free_link_mapping (viewer->link_map);
-	gtk_widget_unref(GTK_WIDGET(viewer->vbox));
-	gtk_widget_unref(GTK_WIDGET(viewer->pdf_view));
-	gtk_widget_unref(GTK_WIDGET(viewer->doc_index_pane));
-	gtk_widget_unref(GTK_WIDGET(viewer->scrollwin));
-	gtk_widget_unref(GTK_WIDGET(viewer->scrollwin_index));
-	g_unlink(viewer->filename);
+	g_object_unref(GTK_WIDGET(viewer->vbox));
+	g_object_unref(GTK_WIDGET(viewer->pdf_view));
+	g_object_unref(GTK_WIDGET(viewer->doc_index_pane));
+	g_object_unref(GTK_WIDGET(viewer->scrollwin));
+	g_object_unref(GTK_WIDGET(viewer->scrollwin_index));
+	claws_unlink(viewer->filename);
 	g_free(viewer->filename);
 	g_free(viewer);
 }
@@ -1422,23 +1550,11 @@ static void pdf_viewer_scroll_one_line(MimeViewer *_viewer, gboolean up)
 
 }
 
-static void button_set_pixmap(GtkWidget *widg, char **button_image) 
-{
-	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-
-	pixmap = mask = NULL;
-	PIXMAP_CREATE(mainwindow_get_mainwindow()->window, pixmap, mask, button_image);
-	gtk_container_add(GTK_CONTAINER(widg), 
-	gtk_image_new_from_pixmap(pixmap, mask));
-	gtk_widget_show_all(widg);
-}
-
 #define BUTTON_H_PADDING 3
-#define ADD_BUTTON_TO_TABLE(widget, xpm) \
+#define ADD_BUTTON_TO_TABLE(widget, stock_image) \
 	widget = gtk_button_new(); \
-	button_set_pixmap(widget, xpm); \
-	gtk_widget_set_size_request(GTK_WIDGET(widget), 26, 26); \
+	img = gtk_image_new_from_stock(stock_image, GTK_ICON_SIZE_MENU); \
+	gtk_button_set_image(GTK_BUTTON(widget), img); \
 	gtk_table_attach(GTK_TABLE(viewer->buttons_table), GTK_WIDGET(widget), \
 				col, col+1, 0, 1, 0, 0, BUTTON_H_PADDING, 0); \
 	col++;
@@ -1527,9 +1643,9 @@ static MimeViewer *pdf_viewer_create(void)
 	GtkCellRenderer *renderer;
 	GtkTreeStore *tree_store;
 	GtkWidget *sep;
+	GtkWidget *img;
 	gint col = 0;
 
-
 	viewer = g_new0(PdfViewer, 1);
 	debug_print("pdf_viewer_create\n");
     
@@ -1577,11 +1693,13 @@ static MimeViewer *pdf_viewer_create(void)
 	gtk_widget_set_size_request(viewer->frame_index, 18, -1);
 	gtk_frame_set_label(GTK_FRAME(viewer->frame_index), _("Document Index"));
 
-	viewer->button_bar_tips = gtk_tooltips_new();
+#if !(GTK_CHECK_VERSION(2,12,0))
+	viewer->button_bar_tips = tips;
+#endif
 
 	ADD_SEP_TO_TABLE
-	ADD_BUTTON_TO_TABLE(viewer->first_page, first_arrow_xpm)
-	ADD_BUTTON_TO_TABLE(viewer->prev_page, left_arrow_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->first_page, GTK_STOCK_GOTO_FIRST)
+	ADD_BUTTON_TO_TABLE(viewer->prev_page, GTK_STOCK_GO_BACK)
 	viewer->cur_page = gtk_spin_button_new_with_range(0.0, 0.0, 1.0);
 	viewer->zoom_scroll = gtk_spin_button_new_with_range(0.20, 8.0, 0.20);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(viewer->zoom_scroll), 1.0);
@@ -1595,27 +1713,26 @@ static MimeViewer *pdf_viewer_create(void)
 					0);
 	col++;
 
-	ADD_BUTTON_TO_TABLE(viewer->next_page, right_arrow_xpm)
-	ADD_BUTTON_TO_TABLE(viewer->last_page, last_arrow_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->next_page, GTK_STOCK_GO_FORWARD)
+	ADD_BUTTON_TO_TABLE(viewer->last_page, GTK_STOCK_GOTO_LAST)
 	ADD_SEP_TO_TABLE
-	ADD_BUTTON_TO_TABLE(viewer->zoom_fit, zoom_fit_xpm)
-	ADD_BUTTON_TO_TABLE(viewer->zoom_in, zoom_in_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->zoom_fit, GTK_STOCK_ZOOM_FIT)
+	ADD_BUTTON_TO_TABLE(viewer->zoom_in, GTK_STOCK_ZOOM_IN)
 	gtk_table_attach(GTK_TABLE(viewer->buttons_table), GTK_WIDGET(viewer->zoom_scroll),
 					col, col+1, 
 					0, 1, 0, 0, 
 					BUTTON_H_PADDING, 
 					0);
 	col++;
-	ADD_BUTTON_TO_TABLE(viewer->zoom_out, zoom_out_xpm)
-	ADD_BUTTON_TO_TABLE(viewer->zoom_width, zoom_width_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->zoom_out, GTK_STOCK_ZOOM_OUT)
+	ADD_BUTTON_TO_TABLE(viewer->zoom_width, GTK_STOCK_FULLSCREEN)
 	ADD_SEP_TO_TABLE
-	ADD_BUTTON_TO_TABLE(viewer->rotate_left, rotate_left_xpm)
-	ADD_BUTTON_TO_TABLE(viewer->rotate_right, rotate_right_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->rotate_left, GTK_STOCK_UNDO)
+	ADD_BUTTON_TO_TABLE(viewer->rotate_right, GTK_STOCK_REDO)
 	ADD_SEP_TO_TABLE
-	ADD_BUTTON_TO_TABLE(viewer->doc_info, doc_info_xpm)
+	ADD_BUTTON_TO_TABLE(viewer->doc_info, GTK_STOCK_INFO)
 
-	viewer->doc_index = gtk_toggle_button_new();
-	button_set_pixmap(viewer->doc_index, doc_index_xpm);
+	viewer->doc_index = GTK_WIDGET(gtk_toggle_tool_button_new_from_stock(GTK_STOCK_INDEX));
 	gtk_widget_set_size_request(GTK_WIDGET(viewer->doc_index), 26, 26);
 	gtk_table_attach(GTK_TABLE(viewer->buttons_table), GTK_WIDGET(viewer->doc_index),
 					col, col+1, 
@@ -1674,14 +1791,12 @@ static MimeViewer *pdf_viewer_create(void)
 
 	/* end treeview */
 
-	stock_pixmap_gdk(viewer->hbox, 
+	stock_pixbuf_gdk(viewer->hbox, 
 			STOCK_PIXMAP_MIME_TEXT_PLAIN, 
-			&viewer->icon_pixmap, 
-			&viewer->icon_bitmap);
+			&viewer->icon_pixbuf);
 
-	gtk_image_set_from_pixmap(GTK_IMAGE(viewer->icon_type), 
-				viewer->icon_pixmap, 
-				viewer->icon_bitmap);
+	gtk_image_set_from_pixbuf(GTK_IMAGE(viewer->icon_type), 
+				viewer->icon_pixbuf);
 
 	/* pack widgets*/
 	gtk_box_pack_start(GTK_BOX(viewer->hbox), viewer->icon_type_ebox, FALSE, FALSE, 0);
@@ -1697,135 +1812,107 @@ static MimeViewer *pdf_viewer_create(void)
 	gtk_box_pack_start(GTK_BOX(viewer->vbox), viewer->doc_index_pane, TRUE, TRUE, 0);
 	/* show widgets */
 	gtk_widget_show(GTK_WIDGET(viewer->doc_index_pane));
-	gtk_widget_ref(GTK_WIDGET(viewer->doc_index_pane));
+	g_object_ref(GTK_WIDGET(viewer->doc_index_pane));
 	gtk_widget_show(GTK_WIDGET(viewer->scrollwin));
-	gtk_widget_ref(GTK_WIDGET(viewer->scrollwin));
+	g_object_ref(GTK_WIDGET(viewer->scrollwin));
 	gtk_widget_show(GTK_WIDGET(viewer->icon_type_ebox));
-	gtk_widget_ref(GTK_WIDGET(viewer->icon_type_ebox));
+	g_object_ref(GTK_WIDGET(viewer->icon_type_ebox));
 	gtk_widget_show(GTK_WIDGET(viewer->pdf_view_ebox));
-	gtk_widget_ref(GTK_WIDGET(viewer->pdf_view_ebox));
+	g_object_ref(GTK_WIDGET(viewer->pdf_view_ebox));
 	gtk_widget_show(GTK_WIDGET(viewer->scrollwin_index));
-	gtk_widget_ref(GTK_WIDGET(viewer->scrollwin_index));
+	g_object_ref(GTK_WIDGET(viewer->scrollwin_index));
 	gtk_widget_show(GTK_WIDGET(viewer->hbox));
-	gtk_widget_ref(GTK_WIDGET(viewer->hbox));	
+	g_object_ref(GTK_WIDGET(viewer->hbox));	
 	gtk_widget_show(GTK_WIDGET(viewer->vbox));
-	gtk_widget_ref(GTK_WIDGET(viewer->vbox));
+	g_object_ref(GTK_WIDGET(viewer->vbox));
 
 	gtk_widget_show(GTK_WIDGET(viewer->buttons_table));
-	gtk_widget_ref(GTK_WIDGET(viewer->buttons_table));
+	g_object_ref(GTK_WIDGET(viewer->buttons_table));
 
 	gtk_widget_show(GTK_WIDGET(viewer->cur_page));
-	gtk_widget_ref(GTK_WIDGET(viewer->cur_page));
+	g_object_ref(GTK_WIDGET(viewer->cur_page));
 
 	gtk_widget_show(GTK_WIDGET(viewer->first_page));
-	gtk_widget_ref(GTK_WIDGET(viewer->first_page));
+	g_object_ref(GTK_WIDGET(viewer->first_page));
 
 	gtk_widget_show(GTK_WIDGET(viewer->last_page));
-	gtk_widget_ref(GTK_WIDGET(viewer->last_page));
+	g_object_ref(GTK_WIDGET(viewer->last_page));
 
 	gtk_widget_show(GTK_WIDGET(viewer->prev_page));
-	gtk_widget_ref(GTK_WIDGET(viewer->prev_page));
+	g_object_ref(GTK_WIDGET(viewer->prev_page));
 
 	gtk_widget_show(GTK_WIDGET(viewer->next_page));
-	gtk_widget_ref(GTK_WIDGET(viewer->next_page));
+	g_object_ref(GTK_WIDGET(viewer->next_page));
 
 	gtk_widget_show(GTK_WIDGET(viewer->zoom_in));
-	gtk_widget_ref(GTK_WIDGET(viewer->zoom_in));
+	g_object_ref(GTK_WIDGET(viewer->zoom_in));
 	gtk_widget_show(GTK_WIDGET(viewer->zoom_out));
-	gtk_widget_ref(GTK_WIDGET(viewer->zoom_out));
+	g_object_ref(GTK_WIDGET(viewer->zoom_out));
 	gtk_widget_show(GTK_WIDGET(viewer->zoom_fit));
-	gtk_widget_ref(GTK_WIDGET(viewer->zoom_fit));
+	g_object_ref(GTK_WIDGET(viewer->zoom_fit));
 	gtk_widget_show(GTK_WIDGET(viewer->zoom_width));
-	gtk_widget_ref(GTK_WIDGET(viewer->zoom_width));
+	g_object_ref(GTK_WIDGET(viewer->zoom_width));
 
 	gtk_widget_show(GTK_WIDGET(viewer->rotate_right));
-	gtk_widget_ref(GTK_WIDGET(viewer->rotate_right));
+	g_object_ref(GTK_WIDGET(viewer->rotate_right));
 	gtk_widget_show(GTK_WIDGET(viewer->rotate_left));
-	gtk_widget_ref(GTK_WIDGET(viewer->rotate_left));
+	g_object_ref(GTK_WIDGET(viewer->rotate_left));
 	gtk_widget_show(GTK_WIDGET(viewer->doc_info));
-	gtk_widget_ref(GTK_WIDGET(viewer->doc_info));
+	g_object_ref(GTK_WIDGET(viewer->doc_info));
 	gtk_widget_show(GTK_WIDGET(viewer->doc_index));
-	gtk_widget_ref(GTK_WIDGET(viewer->doc_index));
+	g_object_ref(GTK_WIDGET(viewer->doc_index));
 
 	gtk_widget_show(GTK_WIDGET(viewer->doc_label));
-	gtk_widget_ref(GTK_WIDGET(viewer->doc_label));
+	g_object_ref(GTK_WIDGET(viewer->doc_label));
 	gtk_widget_show(GTK_WIDGET(viewer->icon_type));
-	gtk_widget_ref(GTK_WIDGET(viewer->icon_type));	
+	g_object_ref(GTK_WIDGET(viewer->icon_type));	
 	gtk_widget_show(GTK_WIDGET(viewer->pdf_view));
-	gtk_widget_ref(GTK_WIDGET(viewer->pdf_view));
+	g_object_ref(GTK_WIDGET(viewer->pdf_view));
 	gtk_widget_show(GTK_WIDGET(viewer->zoom_scroll));
-	gtk_widget_ref(GTK_WIDGET(viewer->zoom_scroll));
+	g_object_ref(GTK_WIDGET(viewer->zoom_scroll));
 
 	gtk_widget_show(GTK_WIDGET(viewer->index_list));
-	gtk_widget_ref(GTK_WIDGET(viewer->index_list));
+	g_object_ref(GTK_WIDGET(viewer->index_list));
 
 	/* Set Tooltips*/
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->first_page,
-				_("First Page"),
-				NULL);
+	CLAWS_SET_TIP(viewer->first_page,
+				_("First Page"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->prev_page,
-				_("Previous Page"),
-				NULL);
+	CLAWS_SET_TIP(viewer->prev_page,
+				_("Previous Page"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->next_page,
-				_("Next Page"),
-				NULL);
+	CLAWS_SET_TIP(viewer->next_page,
+				_("Next Page"));
 	
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->last_page,
-				_("Last Page"),
-				NULL);
+	CLAWS_SET_TIP(viewer->last_page,
+				_("Last Page"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->zoom_in,
-				_("Zoom In"),
-				NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->zoom_out,
-				_("Zoom Out"),
-				NULL);
+	CLAWS_SET_TIP(viewer->zoom_in,
+				_("Zoom In"));
+	CLAWS_SET_TIP(viewer->zoom_out,
+				_("Zoom Out"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->zoom_fit,
-				_("Fit Page"),
-				NULL);
+	CLAWS_SET_TIP(viewer->zoom_fit,
+				_("Fit Page"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->zoom_width,
-				_("Fit Page Width"),
-				NULL);
+	CLAWS_SET_TIP(viewer->zoom_width,
+				_("Fit Page Width"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->rotate_left,
-				_("Rotate Left"),
-				NULL);
+	CLAWS_SET_TIP(viewer->rotate_left,
+				_("Rotate Left"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->rotate_right,
-				_("Rotate Right"),
-				NULL);
+	CLAWS_SET_TIP(viewer->rotate_right,
+				_("Rotate Right"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->doc_info,
-				_("Document Info"),
-				NULL);
+	CLAWS_SET_TIP(viewer->doc_info,
+				_("Document Info"));
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips), 
-				viewer->doc_index,
-				_("Document Index"),
-				NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips),
-				viewer->cur_page,
-				_("Page Number"),
-				NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(viewer->button_bar_tips),
-				viewer->zoom_scroll,
-				_("Zoom Factor"),
-				NULL);
+	CLAWS_SET_TIP(viewer->doc_index,
+				_("Document Index"));
+	CLAWS_SET_TIP(viewer->cur_page,
+				_("Page Number"));
+	CLAWS_SET_TIP(viewer->zoom_scroll,
+				_("Zoom Factor"));
 	/* Connect Signals */
 	g_signal_connect(G_OBJECT(viewer->cur_page), 
 				    "value-changed", 
@@ -1928,15 +2015,19 @@ static MimeViewerFactory pdf_viewer_factory =
 
 gint plugin_init(gchar **error)
 {
+#ifdef G_OS_UNIX
+	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
+#else
+	bindtextdomain(TEXTDOMAIN, get_locale_dir());
+#endif
 	msg = g_strdup_printf(_("This plugin enables the viewing of PDF and PostScript "
 				"attachments using the Poppler %s Lib and the gs tool.\n\n"
 				"Any feedback is welcome: iwkse@claws-mail.org"
 				),poppler_get_version());
 
-	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
 	bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
-	if (!check_plugin_version(MAKE_NUMERIC_VERSION(2,9,2,72),
+	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,10,41),
 		    VERSION_NUMERIC, _("PDF Viewer"), error)) return -1;
 	
 	mimeview_register_viewer_factory(&pdf_viewer_factory);
