@@ -37,19 +37,6 @@
 #include <messageview.h>
 #include <alertpanel.h>
 
-#include "first_arrow.xpm"
-#include "last_arrow.xpm"
-#include "left_arrow.xpm"
-#include "right_arrow.xpm"
-#include "zoom_fit.xpm"
-#include "zoom_in.xpm"
-#include "zoom_out.xpm"
-#include "zoom_width.xpm"
-#include "rotate_right.xpm"
-#include "rotate_left.xpm"
-#include "doc_info.xpm"
-#include "doc_index.xpm"
-
 /*#ifdef USE_PTHREAD
  *#include <pthread.h>
  * #endif*/
@@ -82,8 +69,7 @@ struct _PdfViewer
 	GtkWidget			*pdf_view_ebox;
 	GtkWidget			*icon_type_ebox;
 	GtkWidget			*icon_type;
-	GdkPixmap			*icon_pixmap;
-	GdkBitmap			*icon_bitmap;
+	GdkPixbuf			*icon_pixbuf;
 	GtkWidget			*doc_label;
 	GtkWidget			*cur_page;
 	GtkWidget			*doc_index_pane;
@@ -104,7 +90,9 @@ struct _PdfViewer
 	GtkWidget			*doc_index;
 	/* end GtkButtons */
 	GtkTable			*table_doc_info;
+#if !GTK_CHECK_VERSION(2,12,0)
 	GtkTooltips			*button_bar_tips;
+#endif
 	PopplerDocument		*pdf_doc;
 	PopplerPage			*pdf_page;
 	PopplerIndexIter	*pdf_index;
