@@ -322,6 +322,45 @@ static PyObject* quicksearch_clear(PyObject *self, PyObject *args)
   return Py_None;
 }
 
+static PyObject* summaryview_select_messages(PyObject *self, PyObject *args)
+{
+  PyObject *olist;
+  MainWindow *mainwin;
+  Py_ssize_t size, iEl;
+  GSList *msginfos;
+
+  mainwin = mainwindow_get_mainwindow();
+  if(!mainwin || !mainwin->summaryview) {
+    PyErr_SetString(PyExc_LookupError, "SummaryView not found");
+    return NULL;
+  }
+
+  if(!PyArg_ParseTuple(args, "O!", &PyList_Type, &olist)) {
+    PyErr_SetString(PyExc_LookupError, "Argument must be a list of MessageInfo objects.");
+    return NULL;
+  }
+
+  msginfos = NULL;
+  size = PyList_Size(olist);
+  for(iEl = 0; iEl < size; iEl++) {
+    PyObject *element = PyList_GET_ITEM(olist, iEl);
+
+    if(!element || !PyObject_TypeCheck(element, clawsmail_messageinfo_get_type_object())) {
+      PyErr_SetString(PyExc_LookupError, "Argument must be a list of MessageInfo objects.");
+      return NULL;
+    }
+
+    msginfos = g_slist_prepend(msginfos, clawsmail_messageinfo_get_msginfo(element));
+  }
+
+  summary_unselect_all(mainwin->summaryview);
+  summary_select_by_msg_list(mainwin->summaryview, msginfos);
+  g_slist_free(msginfos);
+
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
 static PyObject* get_summaryview_selected_message_list(PyObject *self, PyObject *args)
 {
   MainWindow *mainwin;
@@ -341,7 +380,7 @@ static PyObject* get_summaryview_selected_message_list(PyObject *self, PyObject
   list = summary_get_selected_msg_list(mainwin->summaryview);
   for(walk = list; walk; walk = walk->next) {
     PyObject *msg;
-    msg = clawsmail_msginfo_new(walk->data);
+    msg = clawsmail_messageinfo_new(walk->data);
     if(PyList_Append(result, msg) == -1) {
       Py_DECREF(result);
       return NULL;
@@ -360,6 +399,86 @@ static PyObject* is_exiting(PyObject *self, PyObject *args)
     Py_RETURN_FALSE;
 }
 
+static gboolean get_message_list_for_move_or_copy(PyObject *messagelist, PyObject *folder, GSList **list)
+{
+  Py_ssize_t size, iEl;
+  FolderItem *folderitem;
+  
+  *list = NULL;
+
+  folderitem = clawsmail_folder_get_item(folder);
+  if(!folderitem) {
+    PyErr_SetString(PyExc_LookupError, "Brokern Folder object.");
+    return FALSE;
+  }
+
+  size = PyList_Size(messagelist);
+  for(iEl = 0; iEl < size; iEl++) {
+    PyObject *element = PyList_GET_ITEM(messagelist, iEl);
+    MsgInfo *msginfo;
+
+    if(!element || !PyObject_TypeCheck(element, clawsmail_messageinfo_get_type_object())) {
+      PyErr_SetString(PyExc_TypeError, "Argument must be a list of MessageInfo objects.");
+      return FALSE;
+    }
+    
+    msginfo = clawsmail_messageinfo_get_msginfo(element);
+    if(!msginfo) {
+      PyErr_SetString(PyExc_LookupError, "Broken MessageInfo object.");
+      return FALSE;
+    }
+   
+    procmsg_msginfo_set_to_folder(msginfo, folderitem);
+    *list = g_slist_prepend(*list, msginfo);
+  }
+ 
+  return TRUE;
+}
+
+static PyObject* move_or_copy_messages(PyObject *self, PyObject *args, gboolean move)
+{
+  PyObject *messagelist;
+  PyObject *folder;
+  int retval;
+  GSList *list = NULL;
+  
+  retval = PyArg_ParseTuple(args, "O!O!",
+    &PyList_Type, &messagelist,
+    clawsmail_folder_get_type_object(), &folder);
+  if(!retval )
+    return NULL;  
+
+  folder_item_update_freeze();
+  
+  if(!get_message_list_for_move_or_copy(messagelist, folder, &list))
+    goto err;
+  
+  if(move)   
+    procmsg_move_messages(list);
+  else
+    procmsg_copy_messages(list);
+      
+  folder_item_update_thaw();
+  g_slist_free(list);
+  Py_RETURN_NONE;
+
+err:
+  folder_item_update_thaw();
+  g_slist_free(list);
+  return NULL;
+}
+
+static PyObject* move_messages(PyObject *self, PyObject *args)
+{
+  return move_or_copy_messages(self, args, TRUE);
+}
+
+
+static PyObject* copy_messages(PyObject *self, PyObject *args)
+{
+  return move_or_copy_messages(self, args, FALSE);
+}
+
 static PyMethodDef ClawsMailMethods[] = {
     /* public */
     {"get_mainwindow_action_group",  get_mainwindow_action_group, METH_NOARGS,
@@ -411,6 +530,11 @@ static PyMethodDef ClawsMailMethods[] = {
      "\n"
      "Get a list of clawsmail.MessageInfo objects of the current selection."},
 
+    {"summaryview_select_messages", summaryview_select_messages, METH_VARARGS,
+     "summaryview_select_messages(message_list) - select a list of messages in the summary view\n"
+     "\n"
+     "Select a list of clawsmail.MessageInfo objects in the summary view."},
+
     {"is_exiting", is_exiting, METH_NOARGS,
      "is_exiting() - test whether Claws Mail is currently exiting\n"
      "\n"
@@ -419,6 +543,18 @@ static PyMethodDef ClawsMailMethods[] = {
      "plugin is explicitly unloaded, the shutdown script will still be called, but this function will\n"
      "return False."},
 
+    {"move_messages", move_messages, METH_VARARGS,
+     "move_messages(message_list, target_folder) - move a list of messages to a target folder\n"
+     "\n"
+     "Move a list of clawsmail.MessageInfo objects to a target folder.\n"
+     "The target_folder argument has to be a clawsmail.Folder object."},
+
+    {"copy_messages", copy_messages, METH_VARARGS,
+     "copy_messages(message_list, target_folder) - copy a list of messages to a target folder\n"
+     "\n"
+     "Copy a list of clawsmail.MessageInfo objects to a target folder.\n"
+     "The target_folder argument has to be a clawsmail.Folder object."},
+
      /* private */
      {"__gobj", private_wrap_gobj, METH_VARARGS,
       "__gobj(ptr) - transforms a C GObject pointer into a PyGObject\n"
