@@ -24,6 +24,7 @@
 
 #include "clawsmailmodule.h"
 #include "foldertype.h"
+#include "messageinfotype.h"
 
 #include "mainwindow.h"
 #include "account.h"
@@ -35,6 +36,7 @@ typedef struct {
     PyObject_HEAD
     PyObject *ui_manager;
     PyObject *text;
+    PyObject *replyinfo;
     Compose *compose;
 } clawsmail_ComposeWindowObject;
 
@@ -42,31 +44,32 @@ static void ComposeWindow_dealloc(clawsmail_ComposeWindowObject* self)
 {
   Py_XDECREF(self->ui_manager);
   Py_XDECREF(self->text);
+  Py_XDECREF(self->replyinfo);
   self->ob_type->tp_free((PyObject*)self);
 }
 
-#define WRAP_GOBJECT_IN_MEMBER_VAR(ptr, var) \
-  do {                                       \
-    var = get_gobj_from_address(ptr);        \
-    if(var) {                                \
-      tmp = self->var;                       \
-      Py_INCREF(var);                        \
-      self->var = var;                       \
-      Py_XDECREF(tmp);                       \
-      tmp = NULL;                            \
-    }                                        \
-  } while(0)
-
+static void store_py_object(PyObject **target, PyObject *obj)
+{
+  Py_XDECREF(*target);
+  if(obj)
+  {
+    Py_INCREF(obj);
+    *target = obj;
+  }
+  else {
+    Py_INCREF(Py_None);
+    *target = Py_None;
+  }
+}
 
 static void composewindow_set_compose(clawsmail_ComposeWindowObject *self, Compose *compose)
 {
-  PyObject *ui_manager = NULL;
-  PyObject *tmp = NULL;
-  PyObject *text = NULL;
-
   self->compose = compose;
-  WRAP_GOBJECT_IN_MEMBER_VAR(compose->ui_manager, ui_manager);
-  WRAP_GOBJECT_IN_MEMBER_VAR(compose->text, text);
+
+  store_py_object(&(self->ui_manager), get_gobj_from_address(compose->ui_manager));
+  store_py_object(&(self->text), get_gobj_from_address(compose->text));
+
+  store_py_object(&(self->replyinfo), clawsmail_messageinfo_new(compose->replyinfo));
 }
 
 static int ComposeWindow_init(clawsmail_ComposeWindowObject *self, PyObject *args, PyObject *kwds)
@@ -450,6 +453,9 @@ static PyMemberDef ComposeWindow_members[] = {
     {"text", T_OBJECT_EX, offsetof(clawsmail_ComposeWindowObject, text), 0,
      "text - the gtk.TextView widget of the message body"},
 
+    {"replyinfo", T_OBJECT_EX, offsetof(clawsmail_ComposeWindowObject, replyinfo), 0,
+     "replyinfo - The MessageInfo object of the message that is being replied to, or None"},
+
     {NULL}
 };
 
