@@ -153,6 +153,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	curl_easy_setopt(eh, CURLOPT_MAXREDIRS, 3);
 	curl_easy_setopt(eh, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
 	curl_easy_setopt(eh, CURLOPT_NOSIGNAL, 1);
+	curl_easy_setopt(eh, CURLOPT_ENCODING, "");
 #if LIBCURL_VERSION_NUM >= 0x070a00
 	curl_easy_setopt(eh, CURLOPT_SSL_VERIFYPEER, 0);
 	curl_easy_setopt(eh, CURLOPT_SSL_VERIFYHOST, 0);
@@ -579,7 +580,7 @@ static RSSyl_HTMLSymbol symbol_list[] = {
 	{ NULL, NULL },
 };
 
-static gchar *rssyl_replace_html_symbols(gchar *text)
+static gchar *rssyl_replace_html_symbols(const gchar *text)
 {
 	gchar *tmp = NULL, *wtext = g_strdup(text);
 	gint i;
@@ -595,7 +596,7 @@ static gchar *rssyl_replace_html_symbols(gchar *text)
 	return wtext;
 }
 
-gchar *rssyl_format_string(gchar *str, gboolean replace_html, gboolean replace_returns)
+gchar *rssyl_format_string(const gchar *str, gboolean replace_html, gboolean replace_returns)
 {
 	gchar *res = NULL;
 	gchar *tmp = NULL;
@@ -607,7 +608,7 @@ gchar *rssyl_format_string(gchar *str, gboolean replace_html, gboolean replace_r
 	else
 		tmp = g_strdup(str);
 
-	res = rssyl_sanitize_string(tmp);
+	res = rssyl_sanitize_string(tmp, replace_returns);
 	g_free(tmp);
 
 	g_strstrip(res);
@@ -970,7 +971,8 @@ void rssyl_read_existing(RSSylFolderItem *ritem)
 static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 		const RSSylFeedItem *b)
 {
-	gboolean date_publ_eq = FALSE, link_eq = FALSE, title_eq = FALSE;
+	gboolean date_publ_eq = FALSE, date_eq = FALSE;
+	gboolean link_eq = FALSE, title_eq = FALSE;
 	gboolean no_link = FALSE, no_title = FALSE;
 	gchar *atit = NULL, *btit = NULL;
 
@@ -996,8 +998,8 @@ static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 		no_link = TRUE;
 
 	if( (a->title != NULL) && (b->title != NULL) ) {
-		atit = conv_unmime_header(a->title, CS_UTF_8);
-		btit = conv_unmime_header(b->title, CS_UTF_8);
+		atit = conv_unmime_header(a->title, CS_UTF_8, FALSE);
+		btit = conv_unmime_header(b->title, CS_UTF_8, FALSE);
 		if( strcmp(atit, btit) == 0 )
 			title_eq = TRUE;
 		g_free(atit);
@@ -1008,7 +1010,7 @@ static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 	/* If there's no 'published' timestamp for the item, we can only judge
 	 * by item link and title - 'modified' timestamp can have changed if the
 	 * item was updated recently. */
-	if( a->date_published <= 0 ) {
+	if( b->date_published <= 0 && b->date <= 0) {
 		if( link_eq && (title_eq || no_title) )
 			return 0;
 	}
@@ -1018,9 +1020,14 @@ static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 		date_publ_eq = TRUE;
 	}
 
+	if( ((a->date > 0) && (b->date > 0) &&
+			(a->date == b->date)) ) {
+		date_eq = TRUE;
+	}
+
 	/* If 'published' time and item link match, it is reasonable to assume
 	 * it's this item. */
-	if( (link_eq || no_link) && date_publ_eq )
+	if( (link_eq || no_link) && (date_publ_eq || date_eq) )
 		return 0;
 
 	/* Last ditch effort - if everything else is missing, at least titles
@@ -1042,8 +1049,8 @@ static gint rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *new_
 {
 	/* if both have title ... */
 	if( old_item->title && new_item->title ) {
-		gchar *old = conv_unmime_header(old_item->title, CS_UTF_8);
-		gchar *new = conv_unmime_header(new_item->title, CS_UTF_8);
+		gchar *old = conv_unmime_header(old_item->title, CS_UTF_8, FALSE);
+		gchar *new = conv_unmime_header(new_item->title, CS_UTF_8, FALSE);
 		if( strcmp(old, new) ) {	/* ... compare "unmimed" titles */
 			g_free(old);
 			g_free(new);
@@ -1062,8 +1069,8 @@ static gint rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *new_
 
 	/* if both have author ... */
 	if( old_item->author && new_item->author ) {
-		gchar *old = conv_unmime_header(old_item->author, CS_UTF_8);
-		gchar *new = conv_unmime_header(new_item->author, CS_UTF_8);
+		gchar *old = conv_unmime_header(old_item->author, CS_UTF_8, TRUE);
+		gchar *new = conv_unmime_header(new_item->author, CS_UTF_8, TRUE);
 		if( strcmp(old, new) ) {	/* ... compare "unmimed" authors */
 			g_free(old);
 			g_free(new);
@@ -1133,10 +1140,10 @@ static guint rssyl_feed_item_exists(RSSylFolderItem *ritem,
 			else
 				return EXISTS_CHANGED;
 		}
-		return 1;
+		return EXISTS_UNCHANGED;
 	}
 
-	return 0;
+	return EXISTS_NEW;
 }
 
 void rssyl_parse_feed(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
@@ -1674,8 +1681,6 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 	g_return_val_if_fail(parent != NULL, NULL);
 	g_return_val_if_fail(url != NULL, NULL);
 
-	myurl = g_strdup(url);
-
 	if (!strncmp(url, "feed://", 7))
 		myurl = g_strdup(url+7);
 	else if (!strncmp(url, "feed:", 5))
