@@ -41,10 +41,10 @@
 #include "rssyl.h"
 #include "rssyl_gtk.h"
 
-void rssyl_new_feed_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_new_feed_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *new_feed;
 
@@ -52,7 +52,7 @@ void rssyl_new_feed_cb(FolderView *folderview, guint action,
 
 	g_return_if_fail(folderview->selected != NULL);
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
@@ -66,10 +66,10 @@ void rssyl_new_feed_cb(FolderView *folderview, guint action,
 	g_free(new_feed);
 }
 
-void rssyl_new_folder_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_new_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	FolderItem *new_item;
 	gchar *new_folder;
@@ -79,7 +79,7 @@ void rssyl_new_folder_cb(FolderView *folderview, guint action,
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
@@ -117,9 +117,9 @@ void rssyl_new_folder_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-void rssyl_remove_rss_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_remove_rss_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *name, *message;
 	AlertValue aval;
@@ -148,10 +148,10 @@ void rssyl_remove_rss_cb(FolderView *folderview, guint action,
 	folder_destroy(item->folder);
 }
 
-void rssyl_remove_feed_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_remove_feed_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gint response;
 	GtkWidget *dialog, *rmcache_widget = NULL;
@@ -184,7 +184,7 @@ void rssyl_remove_feed_cb(FolderView *folderview, guint action,
 	gtk_widget_destroy(dialog);
 
 	if( folderview->opened == folderview->selected ||
-			gtk_ctree_is_ancestor(ctree,
+			gtk_cmctree_is_ancestor(ctree,
 					folderview->selected,
 					folderview->opened) ) {
 		summary_clear_all(folderview->summaryview);
@@ -210,10 +210,10 @@ void rssyl_remove_feed_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-void rssyl_remove_folder_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+void rssyl_remove_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
@@ -241,7 +241,7 @@ void rssyl_remove_folder_cb(FolderView *folderview, guint action,
 	old_id = folder_item_get_identifier(item);
 
 	if (folderview->opened == folderview->selected ||
-	    gtk_ctree_is_ancestor(ctree,
+	    gtk_cmctree_is_ancestor(ctree,
 				  folderview->selected,
 				  folderview->opened)) {
 		summary_clear_all(folderview->summaryview);
@@ -262,9 +262,9 @@ void rssyl_remove_folder_cb(FolderView *folderview, guint action,
 
 }
 
-void rssyl_refresh_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_refresh_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	RSSylFolderItem *ritem;
 
@@ -274,7 +274,7 @@ void rssyl_refresh_cb(FolderView *folderview, guint action,
 
 	ritem = (RSSylFolderItem *)item;
 
-	if (prefs_common.work_offline && 
+	if (prefs_common_get_prefs()->work_offline && 
 	   !inc_offline_should_override(TRUE,
 			ngettext(
 			   "Claws Mail needs network access in order "
@@ -289,16 +289,16 @@ void rssyl_refresh_cb(FolderView *folderview, guint action,
 	main_window_cursor_normal(mainwindow_get_mainwindow());
 }
 
-void rssyl_refresh_all_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_refresh_all_cb(GtkAction *action, gpointer data)
 {
 	main_window_cursor_wait(mainwindow_get_mainwindow());
 	rssyl_refresh_all_feeds();
 	main_window_cursor_normal(mainwindow_get_mainwindow());
 }
 
-void rssyl_prop_cb(FolderView *folderview, guint action, GtkWidget *widget)
+void rssyl_prop_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	RSSylFolderItem *ritem;
 
@@ -313,9 +313,9 @@ void rssyl_prop_cb(FolderView *folderview, guint action, GtkWidget *widget)
 	rssyl_gtk_prop(ritem);
 }
 
-void rssyl_rename_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+void rssyl_rename_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *new_folder;
 	gchar *name;
@@ -328,7 +328,7 @@ void rssyl_rename_cb(FolderView *folderview, guint action,
 
 	name = trim_string(item->name, 32);
 	message = g_strdup_printf(_("Input new name for '%s':"), name);
-	new_folder = input_dialog(_("Rename folder"), message, name);
+	new_folder = input_dialog(_("Rename folder"), message, item->name);
 	g_free(message);
 	g_free(name);
 	if (!new_folder) return;
@@ -357,9 +357,9 @@ void rssyl_rename_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-void rssyl_import_feed_list_cb(FolderView *folderview, guint action,
-		GtkWidget *widget)
+void rssyl_import_feed_list_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	debug_print("RSSyl: rssyl_import_feed_cb\n");
 
 	FolderItem *item;
