@@ -75,7 +75,7 @@ void spamreport_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = _("SpamReport");
 	path[2] = NULL;
 
