@@ -1427,7 +1427,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	if (!prefs_common_get_prefs()->work_offline) {
 		gchar *err = NULL;
 		gboolean queued_removed = FALSE;
-		gint val = procmsg_send_message_queue(msgpath, &err, folderitem, msgnum, &queued_removed);
+		gint val = procmsg_send_message_queue_with_lock(msgpath, &err, folderitem, msgnum, &queued_removed);
 		if (val == 0) {
 			if (!queued_removed)
 				folder_item_remove_msg(folderitem, msgnum);
