@@ -1393,7 +1393,6 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	GtkWidget *notebook;
 	GtkWidget *maemo_vbox0;
 #endif
-	CLAWS_TIP_DECL();
 
 	if (!watch_cursor)
 		watch_cursor = gdk_cursor_new(GDK_WATCH);
@@ -2059,9 +2058,9 @@ gboolean vcal_meeting_export_calendar(const gchar *path,
 	g_free(internal_file);
 
 	for (cur = subs; cur; cur = cur->next) {
+		/* Not to be freed */
 		icalcomponent *event = (icalcomponent *)cur->data;
 		vcal_manager_icalevent_dump(event, NULL, calendar);
-		icalcomponent_free(event);
 	}
 
 	if (vcalprefs.export_enable || path == NULL) {
