@@ -640,7 +640,7 @@ void vcal_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 
-	path[0] = _("Plugins");
+	path[0] = D_("claws-mail", "Plugins");
 	path[1] = _("vCalendar");
 	path[2] = NULL;
 
